import type { NativeBindings } from './NativeBindings';
import type { AriesAskar, EntryListCountOptions, EntryListFreeOptions, EntryListGetCategoryOptions, EntryListGetNameOptions, EntryListGetTagsOptions, EntryListGetValueOptions, KeyAeadDecryptOptions, KeyAeadEncryptOptions, KeyAeadGetPaddingOptions, KeyAeadGetParamsOptions, KeyAeadRandomNonceOptions, KeyConvertOptions, KeyCryptoBoxOpenOptions, KeyCryptoBoxOptions, KeyCryptoBoxSealOpenOptions, KeyCryptoBoxSealOptions, KeyDeriveEcdh1puOptions, KeyDeriveEcdhEsOptions, KeyEntryListCountOptions, KeyEntryListFreeOptions, KeyEntryListGetAlgorithmOptions, KeyEntryListGetMetadataOptions, KeyEntryListGetNameOptions, KeyEntryListGetTagsOptions, KeyEntryListLoadLocalOptions, KeyFreeOptions, KeyFromJwkOptions, KeyFromKeyExchangeOptions, KeyFromPublicBytesOptions, KeyFromSecretBytesOptions, KeyFromSeedOptions, KeyGenerateOptions, KeyGetAlgorithmOptions, KeyGetEphemeralOptions, KeyGetJwkPublicOptions, KeyGetJwkSecretOptions, KeyGetJwkThumbprintOptions, KeyGetPublicBytesOptions, KeyGetSecretBytesOptions, KeySignMessageOptions, KeyUnwrapKeyOptions, KeyVerifySignatureOptions, KeyWrapKeyOptions, MigrateIndySdkOptions, ScanFreeOptions, ScanNextOptions, ScanStartOptions, SessionCloseOptions, SessionCountOptions, SessionFetchAllKeysOptions, SessionFetchAllOptions, SessionFetchKeyOptions, SessionFetchOptions, SessionInsertKeyOptions, SessionRemoveAllOptions, SessionRemoveKeyOptions, SessionStartOptions, SessionUpdateKeyOptions, SessionUpdateOptions, SetCustomLoggerOptions, SetMaxLogLevelOptions, StoreCloseOptions, StoreCreateProfileOptions, StoreGenerateRawKeyOptions, StoreGetProfileNameOptions, StoreOpenOptions, StoreProvisionOptions, StoreRekeyOptions, StoreRemoveOptions, StoreRemoveProfileOptions } from '@hyperledger/aries-askar-shared';
import { AeadParams, EncryptedBuffer, LocalKeyHandle, EntryListHandle, StoreHandle, SessionHandle, ScanHandle, KeyEntryListHandle } from '@hyperledger/aries-askar-shared';
export declare class ReactNativeAriesAskar implements AriesAskar {
    private ariesAskar;
    constructor(bindings: NativeBindings);
    private handleError;
    private promisify;
    private promisifyWithResponse;
    version(): string;
    getCurrentError(): string;
    clearCustomLogger(): void;
    setCustomLogger(_: SetCustomLoggerOptions): void;
    setDefaultLogger(): void;
    setMaxLogLevel(_: SetMaxLogLevelOptions): void;
    entryListCount(options: EntryListCountOptions): number;
    entryListFree(options: EntryListFreeOptions): void;
    entryListGetCategory(options: EntryListGetCategoryOptions): string;
    entryListGetName(options: EntryListGetNameOptions): string;
    entryListGetTags(options: EntryListGetTagsOptions): string | null;
    entryListGetValue(options: EntryListGetValueOptions): Uint8Array;
    keyAeadDecrypt(options: KeyAeadDecryptOptions): Uint8Array;
    keyAeadEncrypt(options: KeyAeadEncryptOptions): EncryptedBuffer;
    keyAeadGetPadding(options: KeyAeadGetPaddingOptions): number;
    keyAeadGetParams(options: KeyAeadGetParamsOptions): AeadParams;
    keyAeadRandomNonce(options: KeyAeadRandomNonceOptions): Uint8Array;
    keyConvert(options: KeyConvertOptions): LocalKeyHandle;
    keyCryptoBox(options: KeyCryptoBoxOptions): Uint8Array;
    keyCryptoBoxOpen(options: KeyCryptoBoxOpenOptions): Uint8Array;
    keyCryptoBoxRandomNonce(): Uint8Array;
    keyCryptoBoxSeal(options: KeyCryptoBoxSealOptions): Uint8Array;
    keyCryptoBoxSealOpen(options: KeyCryptoBoxSealOpenOptions): Uint8Array;
    keyDeriveEcdh1pu(options: KeyDeriveEcdh1puOptions): LocalKeyHandle;
    keyDeriveEcdhEs(options: KeyDeriveEcdhEsOptions): LocalKeyHandle;
    keyEntryListCount(options: KeyEntryListCountOptions): number;
    keyEntryListFree(options: KeyEntryListFreeOptions): void;
    keyEntryListGetAlgorithm(options: KeyEntryListGetAlgorithmOptions): string;
    keyEntryListGetMetadata(options: KeyEntryListGetMetadataOptions): string | null;
    keyEntryListGetName(options: KeyEntryListGetNameOptions): string;
    keyEntryListGetTags(options: KeyEntryListGetTagsOptions): string | null;
    keyEntryListLoadLocal(options: KeyEntryListLoadLocalOptions): LocalKeyHandle;
    keyFree(options: KeyFreeOptions): void;
    keyFromJwk(options: KeyFromJwkOptions): LocalKeyHandle;
    keyFromKeyExchange(options: KeyFromKeyExchangeOptions): LocalKeyHandle;
    keyFromPublicBytes(options: KeyFromPublicBytesOptions): LocalKeyHandle;
    keyFromSecretBytes(options: KeyFromSecretBytesOptions): LocalKeyHandle;
    keyFromSeed(options: KeyFromSeedOptions): LocalKeyHandle;
    keyGenerate(options: KeyGenerateOptions): LocalKeyHandle;
    keyGetAlgorithm(options: KeyGetAlgorithmOptions): string;
    keyGetEphemeral(options: KeyGetEphemeralOptions): number;
    keyGetJwkPublic(options: KeyGetJwkPublicOptions): string;
    keyGetJwkSecret(options: KeyGetJwkSecretOptions): Uint8Array;
    keyGetJwkThumbprint(options: KeyGetJwkThumbprintOptions): string;
    keyGetPublicBytes(options: KeyGetPublicBytesOptions): Uint8Array;
    keyGetSecretBytes(options: KeyGetSecretBytesOptions): Uint8Array;
    keySignMessage(options: KeySignMessageOptions): Uint8Array;
    keyUnwrapKey(options: KeyUnwrapKeyOptions): LocalKeyHandle;
    keyVerifySignature(options: KeyVerifySignatureOptions): boolean;
    keyWrapKey(options: KeyWrapKeyOptions): EncryptedBuffer;
    scanFree(options: ScanFreeOptions): void;
    scanNext(options: ScanNextOptions): Promise<EntryListHandle | null>;
    scanStart(options: ScanStartOptions): Promise<ScanHandle>;
    sessionClose(options: SessionCloseOptions): Promise<void>;
    sessionCount(options: SessionCountOptions): Promise<number>;
    sessionFetch(options: SessionFetchOptions): Promise<EntryListHandle | null>;
    sessionFetchAll(options: SessionFetchAllOptions): Promise<EntryListHandle | null>;
    sessionFetchAllKeys(options: SessionFetchAllKeysOptions): Promise<KeyEntryListHandle | null>;
    sessionFetchKey(options: SessionFetchKeyOptions): Promise<KeyEntryListHandle | null>;
    sessionInsertKey(options: SessionInsertKeyOptions): Promise<void>;
    sessionRemoveAll(options: SessionRemoveAllOptions): Promise<number>;
    sessionRemoveKey(options: SessionRemoveKeyOptions): Promise<void>;
    sessionStart(options: SessionStartOptions): Promise<SessionHandle>;
    sessionUpdate(options: SessionUpdateOptions): Promise<void>;
    sessionUpdateKey(options: SessionUpdateKeyOptions): Promise<void>;
    storeClose(options: StoreCloseOptions): Promise<void>;
    storeCreateProfile(options: StoreCreateProfileOptions): Promise<string>;
    storeGenerateRawKey(options: StoreGenerateRawKeyOptions): string;
    storeGetProfileName(options: StoreGetProfileNameOptions): Promise<string>;
    storeOpen(options: StoreOpenOptions): Promise<StoreHandle>;
    storeProvision(options: StoreProvisionOptions): Promise<StoreHandle>;
    storeRekey(options: StoreRekeyOptions): Promise<void>;
    storeRemove(options: StoreRemoveOptions): Promise<number>;
    storeRemoveProfile(options: StoreRemoveProfileOptions): Promise<number>;
    migrateIndySdk(options: MigrateIndySdkOptions): Promise<void>;
}
